@@ -4,13 +4,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-var iconSizes = [PlasmaCore.Units.iconSizes.smallMedium,
-                 PlasmaCore.Units.iconSizes.medium,
-                 PlasmaCore.Units.iconSizes.large,
-                 PlasmaCore.Units.iconSizes.huge,
-                 PlasmaCore.Units.iconSizes.large*2,
-                 PlasmaCore.Units.iconSizes.enormous,
-                 PlasmaCore.Units.iconSizes.enormous*2];
+var iconSizes = [Kirigami.Units.iconSizes.smallMedium,
+                 Kirigami.Units.iconSizes.medium,
+                 Kirigami.Units.iconSizes.large,
+                 Kirigami.Units.iconSizes.huge,
+                 Kirigami.Units.iconSizes.large*2,
+                 Kirigami.Units.iconSizes.enormous,
+                 Kirigami.Units.iconSizes.enormous*2];
 
 function iconSizeFromTheme(size) {
     return iconSizes[size];
