@@ -150,7 +150,7 @@ InputDevice *DevicesModel::deviceAt(int row) const
 QHash<int, QByteArray> DevicesModel::roleNames() const
 {
     return {
-        {Qt::DisplayRole, "display"},
+        {Qt::DisplayRole, QByteArrayLiteral("display")},
     };
 }
 
@@ -188,3 +188,5 @@ bool DevicesModel::isSaveNeeded() const
         return dev->isSaveNeeded();
     });
 }
+
+#include "moc_devicesmodel.cpp"
